.. image:: https://github.com/MagicStack/async_gaussdb/workflows/Tests/badge.svg
   :target: https://github.com/MagicStack/async_gaussdb/actions?query=workflow%3ATests+branch%3Amaster
   :alt: GitHub Actions status

.. image:: https://img.shields.io/pypi/status/async_gaussdb.svg?maxAge=2592000?style=plastic
    :target: https://pypi.python.org/pypi/async_gaussdb


=======
async_gaussdb
=======

**async_gaussdb** is a database interface library designed specifically for
GaussDB and Python/asyncio.  async_gaussdb is an efficient, clean implementation
of GaussDB server binary protocol for use with Python's ``asyncio``
framework.

**async_gaussdb** requires Python 3.8 or later and is supported for GaussDB
versions compatible with openGauss.  Other GaussDB versions or other databases implementing
the openGauss protocol *may* work, but are not being actively tested.

Contents
--------

.. toctree::
   :maxdepth: 2

   installation
   usage
   api/index
   faq
